@@ -3,12 +3,16 @@
 
 #include "spvm_typedecl.h"
 
+
+
+
 enum {
   SPVM_DESCRIPTOR_C_ID_MULNUM_T,
   SPVM_DESCRIPTOR_C_ID_POINTER_T,
   SPVM_DESCRIPTOR_C_ID_NATIVE,
   SPVM_DESCRIPTOR_C_ID_PRECOMPILE,
   SPVM_DESCRIPTOR_C_ID_PUBLIC,
+  SPVM_DESCRIPTOR_C_ID_PROTECTED,
   SPVM_DESCRIPTOR_C_ID_PRIVATE,
   SPVM_DESCRIPTOR_C_ID_RW,
   SPVM_DESCRIPTOR_C_ID_RO,
@@ -23,6 +27,7 @@ struct spvm_descriptor {
   int32_t id;
 };
 
+const char* SPVM_DESCRIPTOR_get_name(SPVM_COMPILER* compiler, int32_t id);
 SPVM_DESCRIPTOR* SPVM_DESCRIPTOR_new(SPVM_COMPILER* compiler);
 const char* const* SPVM_DESCRIPTOR_C_ID_NAMES(void);
 
