@@ -309,7 +309,7 @@ int32_t SPVM_COMPILER_compile_spvm(SPVM_COMPILER* compiler, const char* class_na
       }
       case SPVM_OP_C_ID_FIELD_ACCESS: {
         SPVM_FIELD_ACCESS* field_access = op->uv.field_access;
-        field_access->op_term = NULL;
+        field_access->op_invocant = NULL;
         field_access->op_name = NULL;
         field_access->field = NULL;
         SPVM_ALLOCATOR_free_memory_block_tmp(compiler->allocator, field_access);
@@ -596,11 +596,18 @@ int32_t* SPVM_COMPILER_create_spvm_32bit_codes(SPVM_COMPILER* compiler, SPVM_ALL
     else {
       runtime_class->module_dir_id = -1;
     }
-    runtime_class->object_fields_length = class->object_fields_length;
-    runtime_class->object_fields_offset = class->object_fields_offset;
     runtime_class->has_init_block = class->has_init_block;
     runtime_class->is_anon = class->is_anon;
     runtime_class->is_pointer = class->is_pointer;
+    if (class->parent_class_name) {
+      SPVM_CLASS* parent_class = SPVM_HASH_get(compiler->class_symtable, class->parent_class_name, strlen(class->parent_class_name));
+      runtime_class->parent_class_id = parent_class->id;
+    }
+    else {
+      runtime_class->parent_class_id = -1;
+    }
+    
+    runtime_class->fields_byte_size = class->fields_byte_size;
 
     SPVM_CONSTANT_STRING* class_string = SPVM_HASH_get(compiler->constant_string_symtable, class->name, strlen(class->name));
     runtime_class->name_id = class_string->id;
