@@ -27,8 +27,8 @@ Native APIs have its IDs. These IDs are permanently same for the binary compatib
   10 allocator
   11 new_env_raw
   12 free_env_raw
-  13 check_runtime_assignability
-  14 check_runtime_assignability_array_element
+  13 isa
+  14 elem_isa
   15 runtime
   16 reserved16
   17 reserved17
@@ -197,6 +197,10 @@ Native APIs have its IDs. These IDs are permanently same for the binary compatib
   180 print_stderr
   181 init_env,
   182 call_init_blocks
+  183 get_class_id
+  184 new_stack
+  185 free_stack
+  186 get_instance_method_id_super
 
 =head2 class_vars_heap
 
@@ -295,15 +299,15 @@ Create a new raw envriment.
 
 Free the raw environemt that is created by L</"new_env_raw">.
 
-=head2 check_runtime_assignability
+=head2 isa
 
-  int32_t (*check_runtime_assignability)(SPVM_ENV* env, SPVM_VALUE* stack, int32_t cast_basic_type_id, int32_t cast_type_dimension, void* object);
+  int32_t (*isa)(SPVM_ENV* env, SPVM_VALUE* stack, void* object, int32_t cast_basic_type_id, int32_t cast_type_dimension);
 
-Check the runtime type assignability of an object.
+Perform C<isa> operation.
 
-=head2 check_runtime_assignability_array_element
+=head2 elem_isa
 
-  int32_t (*check_runtime_assignability_array_element)(SPVM_ENV* env, SPVM_VALUE* stack, void* array, void* element);
+  int32_t (*elem_isa)(SPVM_ENV* env, SPVM_VALUE* stack, void* array, void* element);
 
 Check the runtime type assignability of an array element.
 
@@ -1302,11 +1306,11 @@ B<Examples:>
 
 =head2 new_object_by_name
 
-  void* (*new_object_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, const char* class_name, int32_t* exception_flag, const char* file, int32_t line);
+  void* (*new_object_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, const char* class_name, int32_t* error, const char* file, int32_t line);
 
 This is same as C<new_object> function, but you can specify class name directry.
 
-If function is succeeded, C<exception_flag> is set to 0. If a exception occurs, C<exception_flag> is set to 1. 
+If function is succeeded, C<error> is set to 0. If a exception occurs, C<error> is set to 1. 
 
 B<Examples:>
 
@@ -1316,11 +1320,11 @@ B<Examples:>
 
 =head2 new_pointer_by_name
 
-  void* (*new_pointer_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, const char* class_name, void* pointer, int32_t* exception_flag, const char* file, int32_t line);
+  void* (*new_pointer_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, const char* class_name, void* pointer, int32_t* error, const char* file, int32_t line);
 
 This is same as C<new_pointer> function, but you can specify class name directry.
 
-If function is succeeded, C<exception_flag> is set to 0. If a exception occurs, C<exception_flag> is set to 1. 
+If function is succeeded, C<error> is set to 0. If a exception occurs, C<error> is set to 1. 
 
   int32_t e;
   void* minimal = env->new_pointer_by_name(env, stack, "TestCase::Pointer", pointer, &e, __FILE__, __LINE__);
@@ -1330,11 +1334,11 @@ If function is succeeded, C<exception_flag> is set to 0. If a exception occurs,
 
   void (*set_field_byte_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, void* object,
     const char* class_name, const char* field_name, int8_t value,
-    int32_t* exception_flag, const char* file, int32_t line);
+    int32_t* error, const char* file, int32_t line);
 
 This is same as C<set_field_byte> function, but you can specify class name and field name directry.
 
-If function is succeeded, C<exception_flag> is set to 0. If a exception occurs, C<exception_flag> is set to 1. 
+If function is succeeded, C<error> is set to 0. If a exception occurs, C<error> is set to 1. 
 
 B<Examples:>
 
@@ -1346,11 +1350,11 @@ B<Examples:>
 
   void (*set_field_short_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, void* object,
     const char* class_name, const char* field_name, int16_t value,
-    int32_t* exception_flag, const char* file, int32_t line);
+    int32_t* error, const char* file, int32_t line);
 
 This is same as C<set_field_short> function, but you can specify class name and field name directry.
 
-If function is succeeded, C<exception_flag> is set to 0. If a exception occurs, C<exception_flag> is set to 1. 
+If function is succeeded, C<error> is set to 0. If a exception occurs, C<error> is set to 1. 
 
 B<Examples:>
 
@@ -1362,11 +1366,11 @@ B<Examples:>
 
   void (*set_field_int_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, void* object,
     const char* class_name, const char* field_name, int32_t value,
-    int32_t* exception_flag, const char* file, int32_t line);
+    int32_t* error, const char* file, int32_t line);
 
 This is same as C<set_field_int> function, but you can specify class name and field name directry.
 
-If function is succeeded, C<exception_flag> is set to 0. If a exception occurs, C<exception_flag> is set to 1. 
+If function is succeeded, C<error> is set to 0. If a exception occurs, C<error> is set to 1. 
 
 B<Examples:>
 
@@ -1378,11 +1382,11 @@ B<Examples:>
 
   void (*set_field_long_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, void* object,
     const char* class_name, const char* field_name, int64_t value,
-    int32_t* exception_flag, const char* file, int32_t line);
+    int32_t* error, const char* file, int32_t line);
 
 This is same as C<set_field_long> function, but you can specify class name and field name directry.
 
-If function is succeeded, C<exception_flag> is set to 0. If a exception occurs, C<exception_flag> is set to 1. 
+If function is succeeded, C<error> is set to 0. If a exception occurs, C<error> is set to 1. 
 
 B<Examples:>
 
@@ -1394,11 +1398,11 @@ B<Examples:>
 
   void (*set_field_float_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, void* object,
     const char* class_name, const char* field_name, float value,
-    int32_t* exception_flag, const char* file, int32_t line);
+    int32_t* error, const char* file, int32_t line);
 
 This is same as C<set_field_float> function, but you can specify class name and field name directry.
 
-If function is succeeded, C<exception_flag> is set to 0. If a exception occurs, C<exception_flag> is set to 1. 
+If function is succeeded, C<error> is set to 0. If a exception occurs, C<error> is set to 1. 
 
 B<Examples:>
 
@@ -1410,11 +1414,11 @@ B<Examples:>
 
   void (*set_field_double_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, void* object,
     const char* class_name, const char* field_name, double value,
-    int32_t* exception_flag, const char* file, int32_t line);
+    int32_t* error, const char* file, int32_t line);
 
 This is same as C<set_field_double> function, but you can specify class name and field name directry.
 
-If function is succeeded, C<exception_flag> is set to 0. If a exception occurs, C<exception_flag> is set to 1. 
+If function is succeeded, C<error> is set to 0. If a exception occurs, C<error> is set to 1. 
 
 B<Examples:>
 
@@ -1426,11 +1430,11 @@ B<Examples:>
 
   void (*set_field_object_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, void* object,
     const char* class_name, const char* field_name, const char* signature, void* value,
-    int32_t* exception_flag, const char* file, int32_t line);
+    int32_t* error, const char* file, int32_t line);
 
 This is same as C<set_field_object> function, but you can specify class name and field name directry.
 
-If function is succeeded, C<exception_flag> is set to 0. If a exception occurs, C<exception_flag> is set to 1. 
+If function is succeeded, C<error> is set to 0. If a exception occurs, C<error> is set to 1. 
 
 B<Examples:>
 
@@ -1442,11 +1446,11 @@ B<Examples:>
 
   int8_t (*get_field_byte_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, void* object,
     const char* class_name, const char* field_name,
-    int32_t* exception_flag, const char* file, int32_t line);
+    int32_t* error, const char* file, int32_t line);
 
 This is same as C<get_field_byte> function, but you can specify class name and field name directry.
 
-If function is succeeded, C<exception_flag> is get to 0. If a exception occurs, C<exception_flag> is get to 1. 
+If function is succeeded, C<error> is get to 0. If a exception occurs, C<error> is get to 1. 
 
 B<Examples:>
 
@@ -1458,11 +1462,11 @@ B<Examples:>
 
   int16_t (*get_field_short_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, void* object,
     const char* class_name, const char* field_name,
-    int32_t* exception_flag, const char* file, int32_t line);
+    int32_t* error, const char* file, int32_t line);
 
 This is same as C<get_field_short> function, but you can specify class name and field name directry.
 
-If function is succeeded, C<exception_flag> is get to 0. If a exception occurs, C<exception_flag> is get to 1. 
+If function is succeeded, C<error> is get to 0. If a exception occurs, C<error> is get to 1. 
 
 B<Examples:>
 
@@ -1474,11 +1478,11 @@ B<Examples:>
 
   int32_t (*get_field_int_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, void* object,
     const char* class_name, const char* field_name,
-    int32_t* exception_flag, const char* file, int32_t line);
+    int32_t* error, const char* file, int32_t line);
 
 This is same as C<get_field_int> function, but you can specify class name and field name directry.
 
-If function is succeeded, C<exception_flag> is get to 0. If a exception occurs, C<exception_flag> is get to 1. 
+If function is succeeded, C<error> is get to 0. If a exception occurs, C<error> is get to 1. 
 
 B<Examples:>
 
@@ -1490,11 +1494,11 @@ B<Examples:>
 
   int64_t (*get_field_long_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, void* object,
     const char* class_name, const char* field_name,
-    int32_t* exception_flag, const char* file, int32_t line);
+    int32_t* error, const char* file, int32_t line);
 
 This is same as C<get_field_long> function, but you can specify class name and field name directry.
 
-If function is succeeded, C<exception_flag> is get to 0. If a exception occurs, C<exception_flag> is get to 1. 
+If function is succeeded, C<error> is get to 0. If a exception occurs, C<error> is get to 1. 
 
 B<Examples:>
 
@@ -1506,11 +1510,11 @@ B<Examples:>
 
   float (*get_field_float_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, void* object,
     const char* class_name, const char* field_name,
-    int32_t* exception_flag, const char* file, int32_t line);
+    int32_t* error, const char* file, int32_t line);
 
 This is same as C<get_field_float> function, but you can specify class name and field name directry.
 
-If function is succeeded, C<exception_flag> is get to 0. If a exception occurs, C<exception_flag> is get to 1. 
+If function is succeeded, C<error> is get to 0. If a exception occurs, C<error> is get to 1. 
 
 B<Examples:>
 
@@ -1522,11 +1526,11 @@ B<Examples:>
 
   double (*get_field_double_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, void* object,
     const char* class_name, const char* field_name,
-    int32_t* exception_flag, const char* file, int32_t line);
+    int32_t* error, const char* file, int32_t line);
 
 This is same as C<get_field_double> function, but you can specify class name and field name directry.
 
-If function is succeeded, C<exception_flag> is get to 0. If a exception occurs, C<exception_flag> is get to 1. 
+If function is succeeded, C<error> is get to 0. If a exception occurs, C<error> is get to 1. 
 
 B<Examples:>
 
@@ -1538,11 +1542,11 @@ B<Examples:>
 
   void* (*get_field_object_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, void* object,
     const char* class_name, const char* field_name, const char* signature,
-    int32_t* exception_flag, const char* file, int32_t line);
+    int32_t* error, const char* file, int32_t line);
 
 This is same as C<get_field_object> function, but you can specify class name and field name directry.
 
-If function is succeeded, C<exception_flag> is get to 0. If a exception occurs, C<exception_flag> is get to 1. 
+If function is succeeded, C<error> is get to 0. If a exception occurs, C<error> is get to 1. 
 
 B<Examples:>
 
@@ -1554,11 +1558,11 @@ B<Examples:>
 
   void (*set_class_var_byte_by_name)(SPVM_ENV* env, SPVM_VALUE* stack,
     const char* class_name, const char* class_var_name, int8_t value,
-    int32_t* exception_flag, const char* file, int32_t line);
+    int32_t* error, const char* file, int32_t line);
 
 This is same as C<set_class_var_byte> function, but you can specify the class name directry.
 
-If function is succeeded, C<exception_flag> is get to 0. If a exception occurs, C<exception_flag> is get to 1. 
+If function is succeeded, C<error> is get to 0. If a exception occurs, C<error> is get to 1. 
 
 B<Examples:>
 
@@ -1570,11 +1574,11 @@ B<Examples:>
 
   void (*set_class_var_short_by_name)(SPVM_ENV* env, SPVM_VALUE* stack,
     const char* class_name, const char* class_var_name, int16_t value,
-    int32_t* exception_flag, const char* file, int32_t line);
+    int32_t* error, const char* file, int32_t line);
 
 This is same as C<set_class_var_short> function, but you can specify the class name directry.
 
-If function is succeeded, C<exception_flag> is get to 0. If a exception occurs, C<exception_flag> is get to 1. 
+If function is succeeded, C<error> is get to 0. If a exception occurs, C<error> is get to 1. 
 
 B<Examples:>
 
@@ -1586,11 +1590,11 @@ B<Examples:>
 
   void (*set_class_var_int_by_name)(SPVM_ENV* env, SPVM_VALUE* stack,
     const char* class_name, const char* class_var_name, int32_t value,
-    int32_t* exception_flag, const char* file, int32_t line);
+    int32_t* error, const char* file, int32_t line);
 
 This is same as C<set_class_var_int> function, but you can specify the class name directry.
 
-If function is succeeded, C<exception_flag> is get to 0. If a exception occurs, C<exception_flag> is get to 1. 
+If function is succeeded, C<error> is get to 0. If a exception occurs, C<error> is get to 1. 
 
 B<Examples:>
 
@@ -1602,11 +1606,11 @@ B<Examples:>
 
   void (*set_class_var_long_by_name)(SPVM_ENV* env
     const char* class_name, const char* class_var_name, int64_t value,
-    int32_t* exception_flag, const char* file, int32_t line);
+    int32_t* error, const char* file, int32_t line);
 
 This is same as C<set_class_var_long> function, but you can specify the class name directry.
 
-If function is succeeded, C<exception_flag> is get to 0. If a exception occurs, C<exception_flag> is get to 1. 
+If function is succeeded, C<error> is get to 0. If a exception occurs, C<error> is get to 1. 
 
 B<Examples:>
 
@@ -1618,11 +1622,11 @@ B<Examples:>
 
   void (*set_class_var_float_by_name)(SPVM_ENV* env, SPVM_VALUE* stack,
     const char* class_name, const char* class_var_name, float value,
-    int32_t* exception_flag, const char* file, int32_t line);
+    int32_t* error, const char* file, int32_t line);
 
 This is same as C<set_class_var_float> function, but you can specify the class name directry.
 
-If function is succeeded, C<exception_flag> is get to 0. If a exception occurs, C<exception_flag> is get to 1. 
+If function is succeeded, C<error> is get to 0. If a exception occurs, C<error> is get to 1. 
 
 B<Examples:>
 
@@ -1634,11 +1638,11 @@ B<Examples:>
 
   void (*set_class_var_double_by_name)(SPVM_ENV* env, SPVM_VALUE* stack,
     const char* class_name, const char* class_var_name, double value,
-    int32_t* exception_flag, const char* file, int32_t line);
+    int32_t* error, const char* file, int32_t line);
 
 This is same as C<set_class_var_double> function, but you can specify the class name directry.
 
-If function is succeeded, C<exception_flag> is get to 0. If a exception occurs, C<exception_flag> is get to 1. 
+If function is succeeded, C<error> is get to 0. If a exception occurs, C<error> is get to 1. 
 
 B<Examples:>
 
@@ -1650,11 +1654,11 @@ B<Examples:>
 
   void (*set_class_var_object_by_name)(SPVM_ENV* env, SPVM_VALUE* stack,
     const char* class_name, const char* class_var_name, const char* signature, void* value,
-    int32_t* exception_flag, const char* file, int32_t line);
+    int32_t* error, const char* file, int32_t line);
 
 This is same as C<set_class_var_object> function, but you can specify the class name directry.
 
-If function is succeeded, C<exception_flag> is get to 0. If a exception occurs, C<exception_flag> is get to 1. 
+If function is succeeded, C<error> is get to 0. If a exception occurs, C<error> is get to 1. 
 
 B<Examples:>
 
@@ -1666,11 +1670,11 @@ B<Examples:>
 
   int8_t (*get_class_var_byte_by_name)(SPVM_ENV* env, SPVM_VALUE* stack,
     const char* class_name, const char* class_var_name,
-    int32_t* exception_flag, const char* file, int32_t line);
+    int32_t* error, const char* file, int32_t line);
 
 This is same as C<get_class_var_byte> function, but you can specify the class name directry.
 
-If function is succeeded, C<exception_flag> is get to 0. If a exception occurs, C<exception_flag> is get to 1. 
+If function is succeeded, C<error> is get to 0. If a exception occurs, C<error> is get to 1. 
 
 B<Examples:>
 
@@ -1682,11 +1686,11 @@ B<Examples:>
 
   int16_t (*get_class_var_short_by_name)(SPVM_ENV* env, SPVM_VALUE* stack,
     const char* class_name, const char* class_var_name,
-    int32_t* exception_flag, const char* file, int32_t line);
+    int32_t* error, const char* file, int32_t line);
 
 This is same as C<get_class_var_short> function, but you can specify the class name directry.
 
-If function is succeeded, C<exception_flag> is get to 0. If a exception occurs, C<exception_flag> is get to 1. 
+If function is succeeded, C<error> is get to 0. If a exception occurs, C<error> is get to 1. 
 
 B<Examples:>
 
@@ -1698,11 +1702,11 @@ B<Examples:>
 
   int32_t (*get_class_var_int_by_name)(SPVM_ENV* env, SPVM_VALUE* stack,
     const char* class_name, const char* class_var_name,
-    int32_t* exception_flag, const char* file, int32_t line);
+    int32_t* error, const char* file, int32_t line);
 
 This is same as C<get_class_var_int> function, but you can specify the class name directry.
 
-If function is succeeded, C<exception_flag> is get to 0. If a exception occurs, C<exception_flag> is get to 1. 
+If function is succeeded, C<error> is get to 0. If a exception occurs, C<error> is get to 1. 
 
 B<Examples:>
 
@@ -1714,11 +1718,11 @@ B<Examples:>
 
   int64_t (*get_class_var_long_by_name)(SPVM_ENV* env, SPVM_VALUE* stack,
     const char* class_name, const char* class_var_name,
-    int32_t* exception_flag, const char* file, int32_t line);
+    int32_t* error, const char* file, int32_t line);
 
 This is same as C<get_class_var_long> function, but you can specify the class name directry.
 
-If function is succeeded, C<exception_flag> is get to 0. If a exception occurs, C<exception_flag> is get to 1. 
+If function is succeeded, C<error> is get to 0. If a exception occurs, C<error> is get to 1. 
 
 B<Examples:>
 
@@ -1730,11 +1734,11 @@ B<Examples:>
 
   float (*get_class_var_float_by_name)(SPVM_ENV* env, SPVM_VALUE* stack,
     const char* class_name, const char* class_var_name,
-    int32_t* exception_flag, const char* file, int32_t line);
+    int32_t* error, const char* file, int32_t line);
 
 This is same as C<get_class_var_float> function, but you can specify the class name directry.
 
-If function is succeeded, C<exception_flag> is get to 0. If a exception occurs, C<exception_flag> is get to 1. 
+If function is succeeded, C<error> is get to 0. If a exception occurs, C<error> is get to 1. 
 
 B<Examples:>
 
@@ -1746,11 +1750,11 @@ B<Examples:>
 
   double (*get_class_var_double_by_name)(SPVM_ENV* env, SPVM_VALUE* stack,
     const char* class_name, const char* class_var_name,
-    int32_t* exception_flag, const char* file, int32_t line);
+    int32_t* error, const char* file, int32_t line);
 
 This is same as C<get_class_var_double> function, but you can specify the class name directry.
 
-If function is succeeded, C<exception_flag> is get to 0. If a exception occurs, C<exception_flag> is get to 1. 
+If function is succeeded, C<error> is get to 0. If a exception occurs, C<error> is get to 1. 
 
 B<Examples:>
 
@@ -1762,11 +1766,11 @@ B<Examples:>
 
   void* (*get_class_var_object_by_name)(SPVM_ENV* env, SPVM_VALUE* stack,
     const char* class_name, const char* class_var_name, const char* signature,
-    int32_t* exception_flag, const char* file, int32_t line);
+    int32_t* error, const char* file, int32_t line);
 
 This is same as C<get_class_var_object> function, but you can specify the class name directry.
 
-If function is succeeded, C<exception_flag> is get to 0. If a exception occurs, C<exception_flag> is get to 1. 
+If function is succeeded, C<error> is get to 0. If a exception occurs, C<error> is get to 1. 
 
 B<Examples:>
   
@@ -1787,9 +1791,9 @@ B<Examples:>
   int32_t output;
   {
     stack[0].ival = 5;
-    int32_t exception_flag = env->call_class_method_by_name(env, stack, "TestCase::NativeAPI", "my_value", "int(int)", __FILE__, __LINE__);
-    if (exception_flag) {
-      return exception_flag;
+    int32_t error = env->call_class_method_by_name(env, stack, "TestCase::NativeAPI", "my_value", "int(int)", __FILE__, __LINE__);
+    if (error) {
+      return error;
     }
     output = stack[0].ival;
   }
@@ -1806,7 +1810,7 @@ B<Examples:>
 
   const char* (*get_field_string_chars_by_name)(SPVM_ENV* env, SPVM_VALUE* stack, void* object,
     const char* class_name, const char* field_name,
-    int32_t* exception_flag, const char* file, int32_t line);
+    int32_t* error, const char* file, int32_t line);
 
 B<Examples:>
 
@@ -2004,6 +2008,22 @@ Initialize the environment.
 
 Call C<INIT> blocks.
 
+=head2 get_class_id
+
+  int32_t (*get_class_id)(SPVM_ENV* env, const char* class_name);
+
+=head2 new_stack
+
+  SPVM_VALUE* (*new_stack)(SPVM_ENV* env);
+
+=head2 free_stack
+
+  void (*free_stack)(SPVM_ENV* env, SPVM_VALUE* stack);
+
+=head2 get_instance_method_id_super
+
+  int32_t (*get_instance_method_id_super)(SPVM_ENV* env, void* object, const char* method_name, const char* signature);
+
 =head1 Compiler Native API
 
 L<SPVM::Document::NativeAPI::Compiler>
