@@ -1,14 +1,14 @@
-=head1 Name
+=head1 NAME
 
 SPVM::Document::NativeModule - How to write the native module
 
-=head1 Description
+=head1 DESCRIPTION
 
 The native module is the module that is implemented by native language such as C<C language> or C<C++>.
 
 =head1 Native Method Declaration
 
-A native method declaration are written using the method attribute C<native> in a SPVM module file. The method can't have the block. it ends with a semicolon.
+A native method declaration are written using the method descriptor C<native> in a SPVM module file. The method can't have the block. it ends with a semicolon.
 
   # SPVM/Foo/Bar.spvm
   class Foo::Bar {
@@ -24,7 +24,7 @@ A native config file is needed for the native module. The extension is C<config>
 
 If the native config file does not exist, an exception occurs.
 
-Native config files are writen by Perl. It must return L<Builder::Config|SPVM::Builder::Config> object. Otherwise an exception will occur.
+Native config files are writen by Perl. It must return L<Builder::Config|SPVM::Builder::Config> object, otherwise an exception occurs.
 
 I show some examples of native config files.
 
@@ -520,7 +520,7 @@ The exception is stored in env.
 
 There is a type called pointer type in SPVM, but I will explain how to use it.
 
-The pointer type definition specifies the pointer_t attribute in the SPVM class definition. Pointer types cannot have field definitions. This example describes how to use the C standard "struct tm" as a pointer type.
+The pointer type definition specifies the pointer_t descriptor in the SPVM class definition. Pointer types cannot have field definitions. This example describes how to use the C standard "struct tm" as a pointer type.
 
   # SPVM/MyTimeInfo.spvm
   class MyTimeInfo : pointer_t {
@@ -544,7 +544,7 @@ Next is the definition on the C language side.
   int32_t SPVM__MyTimeInfo__new(SPVM_ENV* env, SPVM_VALUE* stack) {
 
     // Alloc strcut tm
-    void* tm_ptr = env->new_memory_stack(env, stack, sizeof (struct tm));
+    void* tm_ptr = env->alloc_memory_block_zero (sizeof (struct tm));
 
     // Create strcut tm instance
     void* tm_obj = env->new_pointer(env, stack, "MyTimeInfo", tm_ptr);
@@ -574,10 +574,10 @@ Next is the definition on the C language side.
     return 0;
   }
 
-In the constructor new, the memory of "struct tm" is first allocated by the new_memory_stack function. This is a function that reserves one memory block in SPVM. Similar to malloc, this function increments the memory block count by one, making it easier to spot memory leaks.
+In the constructor new, the memory of "struct tm" is first allocated by the alloc_memory_block_zero function. This is a function that reserves one memory block in SPVM. Similar to malloc, this function increments the memory block count by one, making it easier to spot memory leaks.
 
   // Alloc strcut tm
-  void* tm_ptr = env->new_memory_stack(env, stack, sizeof (struct tm));
+  void* tm_ptr = env->alloc_memory_block_zero (sizeof (struct tm));
 
 Next, use the new_pointer function to create a new pointer type object with MyTimeInfo associated with it in the allocated memory.
 
@@ -611,7 +611,7 @@ The last is the destructor. Be sure to define a destructor, as the allocated mem
     return 0;
   }
 
-Execute the free_memory_block function to free the memory. Be sure to free the memory allocated by new_memory_stack with the free_memory_block function. Releases the memory and decrements the memory block count by one.
+Execute the free_memory_block function to free the memory. Be sure to free the memory allocated by alloc_memory_block_zero with the free_memory_block function. Releases the memory and decrements the memory block count by one.
 
 =head1 Calling Native API
 
